@@ -1,7 +1,7 @@
 /* Diese Datei wird von autoheader gebraucht, um daraus
    config.h.in zu erzeugen, woraus ./configure dann config.h erzeugt.
    In config.h.in stehen lauter #undefs fr die Dinge, die nachher in
-   config.h definiert sein sollen. autohaeder sucht diese undefs zusammen.
+   config.h definiert sein sollen. autoheader sucht diese undefs zusammen.
    Die meisten kann es automatisch erzeugen (oder in einer globalen
    acconfig.h finden). Aber halt nicht alle. Deshalb diese Datei.
 */
@@ -11,3 +11,6 @@
    read compressed xpm files (with certain restrictions). */
 #undef HAVE_LIBZ
 
+/* Define if you want to compile cuyo with sound enabled. You will need
+   the libmikmod to do that. */
+#undef CUYO_SOUND
