@@ -70,6 +70,12 @@ Blop::Blop(int s):
 
   mDaten[spezvar_kind] = s;
   
+  /* In Zukunft soll das mal nicht mehr mglich sein:
+  if (gGleichZeit) {
+    fprintf(stderr, "Neuer Blop in Gleichzeit\n");
+  }
+  */
+  
   setWillInitEvent(true);
 }
 
@@ -283,7 +289,7 @@ void Blop::animiere() {
         && mDaten[spezvar_kind_beim_letzten_draw_aufruf] != -1) {
        Code * alt_co = ld->mSorten[
                            mDaten[spezvar_kind_beim_letzten_draw_aufruf]
-			 ].getEventCode(event_draw);
+			 ]->getEventCode(event_draw);
        if (alt_co)
          alt_co->busyReset(*this);
     }
@@ -320,6 +326,9 @@ void Blop::animiere() {
         /* Letztes Platz-Bildchen. Im nchsten Schritt in
            nichts verwandeln. */
         mDaten[spezvar_kind] = blopart_keins;
+	/* Wenn der Blop sich als Gras verhlt, dann soll er das nicht
+	   mehr tun, nachdem er geplatzt ist. */
+	mDaten[spezvar_goalblob] = 0;
 	mAmPlatzen = 0;
       }
     } // if Blop ist am platzen
@@ -354,16 +363,17 @@ bool Blop::takeUpdaten() {
     werden.
     Die Event-Nummern sind in sorte.h definiert. */
 void Blop::execEvent(int evtnr) {
-  CASSERT(gGleichZeit);
-  
-  CASSERT(!mFreilaufend);
-  /* Wenn ein Blop auf ein Init-Event wartet, darf noch nix anderes
-     aufgerufen werden. (mWillInitEvent wird _vor_ der Event-Versendung
-     auf false gesetzt.) */
-  CASSERT(!mWillInitEvent);
-  
+
   try { // Um die Fehlermeldung zu verbessern...
 
+    CASSERT(gGleichZeit);
+
+    CASSERT(!mFreilaufend);
+    /* Wenn ein Blop auf ein Init-Event wartet, darf noch nix anderes
+       aufgerufen werden. (mWillInitEvent wird _vor_ der Event-Versendung
+       auf false gesetzt.) */
+    CASSERT(!mWillInitEvent);
+
     CASSERT(mDaten);
 
     Code * ec = getSorte()->getEventCode(evtnr);
@@ -422,7 +432,7 @@ bool Blop::verbindetMit(const Blop & b) const {
 
 /** Liest die aktuelle Sorte dieses Blops aus den Leveldaten aus. */
 Sorte * Blop::getSorte() const {
-  return &ld->mSorten[mDaten[spezvar_kind]];
+  return ld->mSorten[mDaten[spezvar_kind]];
 }
 
 /** Fragt beim Besitzer an, in welche Richtungen dieser Blop
@@ -578,6 +588,9 @@ int Blop::getVariable(const Variable & v) const {
     }
   }
 
+  case variable_fall:
+    return mBesitzer->getFall(v.getWelcherFall())->getVariable(v.getNummer());
+
   default:
     CASSERT(false);
   }
@@ -623,6 +636,10 @@ void Blop::setVariable(const Variable & v, int wert, int op) {
     }
     break;
   }
+  case variable_fall:
+    mBesitzer->getFall(v.getWelcherFall())
+      ->setVariable(v.getNummer(), wert, op);
+    break;
   default:
     CASSERT(false);
   }
