@@ -40,6 +40,7 @@
 
 
 class Blop;
+class Spielfeld;
 
 /**Klasse, die Blops "besitzt" und von ihrem Besitztum
 erfahren mchte, wenn es sich verndert.
@@ -48,6 +49,7 @@ erfahren mchte, wenn es sich verndert.
 
 class BlopBesitzer {
 public:
+  BlopBesitzer(Spielfeld * spf);
   virtual ~BlopBesitzer() {}
   /** Da BlopGitter der einzige BlopBesitzer ist, der diese Methode
       berschreiben mchte (naja, fast), kann sie auch gleich daran
@@ -68,9 +70,12 @@ public:
   virtual bool koordOK(int /*x*/, int /*y*/) const {
     return false;
   }
-  virtual int getSpezConst(int /*vnr*/) const {
-    return 0;
-  }
+  virtual const Blop * getFall(int a) const;
+  virtual Blop * getFall(int a);
+  virtual int getSpezConst(int /*vnr*/) const;
+
+protected:
+  Spielfeld * mSpf;
 };
 
 #endif
