@@ -19,7 +19,8 @@
 #include "blopgitter.h"
 
 /** re: true bei rechtem Spieler */
-BlopGitter::BlopGitter(bool re) {
+BlopGitter::BlopGitter(bool re, Spielfeld * spf) : BlopBesitzer(spf) {
+  mSpf = spf;
   for (int x = 0; x < grx; x++)
     for (int y = 0; y <= gry; y++)
       mDaten[x][y].setBesitzer(this, re, x, y);
@@ -109,15 +110,13 @@ bool BlopGitter::getFeldVerbindbar(int x, int y, const Blop & b) const {
 
 
 
-
-/** verschiebt einen Blop (auch wenn er explodiert oder
-    sonstwie grad animiert ist). Was dort hin soll, von wo der Blop weg ist
-    (z. B. blopart_wirklich_keins) kann bergeben werden. */
-void BlopGitter::verschiebBlop(int x1, int y1, int x2, int y2) {
+/*
+void BlopGitter::verschiebBlop(int x1, int y1, int x2, int y2,
+              bool hinterlasseLeer) {
   mDaten[x2][y2] = mDaten[x1][y1];
   mDaten[x1][y1] = Blop(blopart_keins);
 }
-
+*/
 
 
 
@@ -222,3 +221,15 @@ bool BlopGitter::testPlatzSpalte(int x, int y){
   return true;
 }
 
+
+
+/** Sendet an alle Blops das connect-Event. */
+void BlopGitter::sendeConnectEvent() {
+  for (int x = 0; x < grx; x++)
+    for (int y = 0; y < gry; y++)
+      mDaten[x][y].execEvent(event_connect);
+}
+
+
+
+
