@@ -24,6 +24,8 @@
 #include "blopbesitzer.h"
 
 
+class Spielfeld;
+
 
 /**Array, in dem die (festen) Blops eines Spielfelds gespeichert werden.
   *@author Immi
@@ -32,7 +34,7 @@
 class BlopGitter: public BlopBesitzer {
  public:
   /** re: true bei rechtem Spieler */
-  BlopGitter(bool re);
+  BlopGitter(bool re, Spielfeld * spf);
   ~BlopGitter();
 
   /** Lscht alles */
@@ -63,13 +65,10 @@ class BlopGitter: public BlopBesitzer {
   int getFeldArt(int x, int y) const;
 
   /** verschiebt einen Blop (auch wenn er explodiert oder
-      sonstwie grad animiert ist). Was dort hin soll, von wo der Blop weg ist
-      (z. B. blopart_wirklich_keins) kann bergeben werden. */
-  void verschiebBlop(int x1, int y1, int x2, int y2
-		     /*,int bg_sorte = blopart_keins*/);
+      sonstwie grad animiert ist).  */
+  //void verschiebBlop(int x1, int y1, int x2, int y2);
 
-  /** liefert eine VerbindungsBitliste fr den Blop bei x, y. Bezieht sich
-      ggf. auf's Feuer. */
+  /** liefert eine VerbindungsBitliste fr den Blop bei x, y. */
   int getBesitzVerbindungen(int x, int y) const;
   /** liefert true, wenn (x,y) im Spielfeld liegt */
   bool koordOK(int x, int y) const;
@@ -85,10 +84,11 @@ class BlopGitter: public BlopBesitzer {
   /** Liefert true, wenn (x, y) und alle darber liegenden
       Felder frei sind. Wird von Fall bentigt. */
   bool testPlatzSpalte(int x, int y);
+  
+  /** Sendet an alle Blops das connect-Event. */
+  void sendeConnectEvent();
 
  protected:
-	
-
 
   /** _die_ Spielfelddaten. Letzte Zeile fr die Rberreihe. */
   Blop mDaten[grx][gry + 1];
