@@ -80,7 +80,7 @@ Code::Code(STDPAR, Code * f1, Variable * v1): STDINIT,
 
 
 Code::Code(STDPAR, Code * f1,
-           int zahl, int zahl2 /* = 0 */): STDINIT,
+           int zahl /* = 0 */, int zahl2 /* = 0 */): STDINIT,
   mF1(f1), mF2(0), mF3(0), mVar1(0), mVar2(0),
   mZahl(zahl), mZahl2(zahl2)
 {
@@ -111,8 +111,9 @@ Code::Code(STDPAR, __String str): STDINIT,
 #undef STDPAR
 #undef STDINIT
   
-Code::Code(const Code & f): Definition() {
-  kopiere(f);
+Code::Code(DefKnoten * knoten, const Code & f, bool neueBusyNummern):
+       Definition() {
+  kopiere(knoten, f, neueBusyNummern);
 }
 
 
@@ -129,24 +130,24 @@ void Code::deepLoesch() {
 
 
 
-void Code::kopiere(const Code & f) {
+void Code::kopiere(DefKnoten * knoten, const Code & f, bool neueBusyNummern) {
   mArt = f.mArt;
   
   mDateiName = f.mDateiName;
   mZeilenNr = f.mZeilenNr;
 
   if (f.mF1)
-    mF1 = new Code(*f.mF1);
+    mF1 = new Code(knoten, *f.mF1, neueBusyNummern);
   else
     mF1 = 0;
 
   if (f.mF2)
-    mF2 = new Code(*f.mF2);
+    mF2 = new Code(knoten, *f.mF2, neueBusyNummern);
   else
     mF2 = 0;
 
   if (f.mF3)
-    mF3 = new Code(*f.mF3);
+    mF3 = new Code(knoten, *f.mF3, neueBusyNummern);
   else
     mF3 = 0;
 
@@ -165,7 +166,10 @@ void Code::kopiere(const Code & f) {
 
   mString = f.mString;
   
-  mBeschaeftigtNr = f.mBeschaeftigtNr;
+  if (neueBusyNummern)
+    mBeschaeftigtNr = knoten->neueBoolVariable();
+  else
+    mBeschaeftigtNr = f.mBeschaeftigtNr;
 }
 
 
@@ -209,6 +213,8 @@ __String Code::getDefString() const {
     Nachbarstapel-Malungen erhht. */
 int Code::getStapelHoehe(int & nsh) const {
   switch (mArt) {
+    case weiterleit_code:
+      return mF1->getStapelHoehe(nsh);
     case stapel_code:
       return mF1->getStapelHoehe(nsh) + mF2->getStapelHoehe(nsh);
     case push_code:
@@ -260,6 +266,10 @@ int Code::eval(Blop & b) const {
 
     int ret = 0;
     switch (mArt) {
+      case weiterleit_code:
+        mF1->eval(b);
+	setBeschaeftigt(b, mF1->istBeschaeftigt(b));
+        break;
       case stapel_code:
 	mF1->eval(b);
 	mF2->eval(b);
@@ -534,6 +544,17 @@ int Code::eval(Blop & b) const {
 	ret = (z1 >= mZahl && z1 <= mZahl2);
 	break;
       }
+      case ggt_acode: {
+        int a_ = mF1->eval(b);
+        int b_ = mF2->eval(b);
+        while (b_!=0) {
+          int c_ = a_%b_;
+          a_=b_;
+          b_=c_;
+        };
+        ret = a_;
+        break;
+      }
       default: {
 	throw iFehler(_("Internal error in Code::eval(): Unbekannte Code-Art %d"), mArt);
 	break; // mit dem break fhl ich mich wohler...
