@@ -589,16 +589,58 @@ schnellvorlauf:
          hier auch ggf. Tastendrcke abgespielt. */
       Aufnahme::recSchritt(mSpielfeld);
       
-      /* Erst mal den normalen Spielschritt... in einer Gleichzeit, fr
-         evtl. auftretende Events. (Init-Events nicht nicht dabei; die
-	 werden erst beim darauffolgenden animiere() behandelt.) */
+      /*** Die einzelnen Teile eines Spielschritts ausfhren: ***/
+
+      /* Who will be the one killing me for this #define? */
+#define ALLE_SPIELER for (int i = 0; i < mSpielerZahl; i++) mSpielfeld[i]
+
+      //fprintf(stderr, "A\n");
+
+      /* ggf. Message blinken lassen */
+      ALLE_SPIELER->blinkeMessage();
+
+      /* Hetzrand runterbewegen; evtl. sterben */
+      ALLE_SPIELER->bewegeHetzrand();
+      
+      /* Evtl. zufllige Graue an die Spieler senden. (Blops werden nicht
+         erzeugt; es wird nur gespeichert, dass das noch Graue auf das
+	 ankommen warten. */
+      ALLE_SPIELER->zufallsGraue();
+      
+      /* Reihen hin/her. (In einer Gleichzeit, fr evtl. auftretende events.) */
       Blop::beginGleichzeitig();
-      for (int i = 0; i < mSpielerZahl; i++)
-        mSpielfeld[i]->spielSchritt();
+      ALLE_SPIELER->fallSchritt();
       Blop::endGleichzeitig();
+      
+      /* Reihen hin/her. (In einer Gleichzeit, fr evtl. auftretende events.) */
+      Blop::beginGleichzeitig();
+      ALLE_SPIELER->rueberReihenSchritt();
+      Blop::endGleichzeitig();
+      
+      /* Neue explosionen testen. Da inzwischen vielleicht neue Blops
+         entstanden sind und alle einen event bekommen, erst mal fehlende
+	 init-Events senden. Sollte in Zukunft automatisch am Anfang
+	 jeder Gleichzeit passieren. */
+      Blop::sendeFehlendeInitEvents();
+      Blop::beginGleichzeitig();
+      ALLE_SPIELER->testeFlopp();
+      Blop::endGleichzeitig();
+
+      //fprintf(stderr, "B\n");
+     
+      /* Rest vom normalen Spielschritt */
+      Blop::beginGleichzeitig();
+      ALLE_SPIELER->spielSchritt();
+      Blop::endGleichzeitig();
+
+      //fprintf(stderr, "C\n");
+
+#undef ALLE_SPIELER
 
       /* Animationen und Grafik-Ausgabe */
       animiere();
+      
+      
 
       /* Ggf. auch einen Spielschritt fr die KI */
       if (mGegenKI)
@@ -821,17 +863,27 @@ bool Cuyo::startLevel() {
   /* Hier ist die Stelle, wo wir darauf gucken, wie viele Spieler mitspielen;
      nur fr so viele Spieler wird das Spiel wirklich gestartet */
   for (int i = 0; i < mSpielerZahl; i++) {
-    
+
     mSpielfeld[i]->startLevel();
+    __String PlatzAnzahlFormat;
+    if (ld->mPlatzAnzahlMin == ld->mPlatzAnzahlMax)
+      PlatzAnzahlFormat.sprintf(_("%d"),ld->mPlatzAnzahlMin);
+    else
+      if (ld->mPlatzAnzahlAndere)
+	PlatzAnzahlFormat.sprintf(_("between %d and %d"),
+				  ld->mPlatzAnzahlMin,ld->mPlatzAnzahlMax);
+      else
+	PlatzAnzahlFormat.sprintf(_("%d or %d"),
+				  ld->mPlatzAnzahlMin,ld->mPlatzAnzahlMax);
     __String s;
     s.sprintf(_("Score: %d\n\n"
                 "Level %d\n%s\nby %s\n\n"
-                "%d blops explode\n%s\n"
+                "%s blops explode\n%s\n"
 		"%s\n\n"
 		"Space = Start"),
 	    mPunkte[i],
 	    mLevelNr, ld->mLevelName.data(), ld->mLevelAutor.data(),
-	    ld->mPlatzAnzahl,
+	    (const char *) PlatzAnzahlFormat,
 	    ld->mGrasBeiKettenreaktion ? "Chain reaction necessary\n" : "",
 	    ld->mBeschreibung.data());
     /* Kein update-Event verschicken; beim animiere()-Aufruf wird
