@@ -27,7 +27,7 @@
 
 KIPlayer::KIPlayer(Spielfeld * sp): mSp(sp) {
   mDaten = mSp->getDatenPtr();
-  mFall = mSp->getFallPtr();
+  mFall = mSp->getFall();
 }
 KIPlayer::~KIPlayer(){
 }
@@ -120,7 +120,7 @@ int KIPlayer::bewerteBlop(int x, int dy, int f) {
   int ret = -ld->mKINHoehe * gry / yr;
 	
   /* Womit verbinden wir? */
-  for (NachbarIterator i(&ld->mSorten[f], x, y); i; ++i)
+  for (NachbarIterator i(ld->mSorten[f], x, y); i; ++i)
     if (mDaten->koordOK(i.mX, i.mY)) {
       if (mDaten->getFeld(i.mX, i.mY).getFarbe() == f)
 	ret += ld->mKINAnFarbe;
