@@ -35,20 +35,22 @@
 char spezvar_namen[spezvar_anz][22] = {
   "file", "pos", "kind", "version", "qu",
   "out1", "out2",
-  "" // kind_beim_letzten_draw_aufruf; ist nicht fr den User gedacht.
+  "", // kind_beim_letzten_draw_aufruf; ist nicht fr den User gedacht.
+  "inhibit", "goalblob"
 };
 
 int spezvar_default[spezvar_anz] = {
   0, 0, blopart_ausserhalb, 0, viertel_alle,
   spezvar_out_nichts, spezvar_out_nichts,
-  -1
+  -1,
+  0, 0
 };
 
 
 /* Reihenfolge -1, -2, -3, ... */
 char spezconst_namen[spezconst_anz][22] = {
   "turn", "connect", "falling", "size", "loc_x", "loc_y", "loc_p",
-  "players", "falling_fast", "exploding"
+  "players", "falling_fast", "exploding", "loc_xx", "loc_yy"
 };
 
 int spezconst_default[spezconst_anz] = {
@@ -57,8 +59,9 @@ int spezconst_default[spezconst_anz] = {
 };
 
 
-int const_anz = (21+2);
-char const_namen[27][22] = {
+#define const_anz (21+2+2*9)
+//int const_anz = feste_konst_anz;
+char const_namen[const_anz][22] = {
   /* Viertelstckchen */
   "Q_ALL",
   "Q_TL", "Q_TR", "Q_BL", "Q_BR",
@@ -68,12 +71,16 @@ char const_namen[27][22] = {
   "Q_TL_BR", "Q_TR_BR", "Q_BL_BR", "Q_BR_BR",
   
   /* Verwandlungsziele */
-  "nothing", "outside"
+  "nothing", "outside",
+  /* Buchstaben, die in den Strings in Nachbariterator verwendet werden. */
+  /*   A        B         C        D         E          F          G          H          I */
+  "DIR_U", "DIR_UR", "DIR_R", "DIR_DR", "DIR_UUL", "DIR_UUR", "DIR_RRU", "DIR_RRD", "DIR_F",
+  "DIR_D", "DIR_DL", "DIR_L", "DIR_UL", "DIR_DDR", "DIR_DDL", "DIR_LLD", "DIR_LLU", "DIR_B"
 };
 
 /* Eigentlich sollten hier die Konstanten aus bilddatei.h verwendet werden;
    das wre aber so viel Tipparbeit... */
-int const_werte[26] = {
+int const_werte[const_anz] = {
   /* Viertelstckchen */
   viertel_alle,
   0, 5, 10, 15,
@@ -83,7 +90,11 @@ int const_werte[26] = {
   12, 13, 14, 15,
   
   /* Verwandlungsziele */
-  blopart_keins, blopart_ausserhalb
+  blopart_keins, blopart_ausserhalb,
+  
+  /* Richtungskonstanten fr inhibit */
+  0x00000001, 0x00000002, 0x00000004, 0x00000008, 0x00000010, 0x00000020, 0x00000040, 0x00000080, 0x00000100,
+  0x00010000, 0x00020000, 0x00040000, 0x00080000, 0x00100000, 0x00200000, 0x00400000, 0x00800000, 0x01000000
 };
 
 
@@ -297,9 +308,10 @@ void DefKnoten::speicherPicsConst(Knoten * picsliste) {
     ListenKnoten * lki = (ListenKnoten*) picsliste;
     for (int i = 0; i < lki->getLaenge(); i++) {
       /* picsEndungWeg() steht in global.* */
-      __String varna = picsEndungWeg(lki->getWort(i));
+      __String varna = picsEndungWeg(lki->getKernDatum(i,type_WortDatum)
+				     ->getWort());
       speicherDefinition(namespace_variable, varna,
-          new VarDefinition(varna, i, vd_konstante)
+          new VarDefinition(varna, lki->getLaengeBis(i), vd_konstante)
         );
      }
   }
@@ -316,7 +328,8 @@ void DefKnoten::speicherKnotenConst(Knoten * nameKnoten, int wert) {
   if (nameKnoten->type() == type_ListenKnoten) {
     ListenKnoten * lk = (ListenKnoten*) nameKnoten;
     if (lk->getLaenge() == 1) {
-      __String varna = picsEndungWeg(lk->getWort(0));
+      __String varna = picsEndungWeg(lk->getDatum(0,type_WortDatum)
+				     ->getWort());
       speicherDefinition(namespace_variable, varna,
           new VarDefinition(varna, wert, vd_konstante)
         );
@@ -371,7 +384,7 @@ void DefKnoten::speicherDefinition(int ns, const __String & na,
 
 
 /** Liefert eine Code-Definition aus diesem Speicher oder von
-    weiter oben. Throwt bei nichtexistenz.
+    weiter oben. Throwt bei Nichtexistenz.
     Achtung: Behlt den Besitz an der Defintion. */
 Definition * DefKnoten::getDefinition(int ns, __String na) {
 
@@ -483,17 +496,96 @@ __String ListenKnoten::toString() const {
 
 
 
-__String ListenKnoten::getWort(int nr) {
-  Knoten * k = mKinder.at(nr);
-  CASSERT(k->type() == type_WortKnoten);
-  return ((WortKnoten *) k)->getWort();
+int ListenKnoten::getVielfachheit(int nr) const {
+  DatenKnoten * k = (DatenKnoten *) (mKinder.at(nr));
+  CASSERT(k->type() == type_DatenKnoten);
+  if (k->datatype()==type_VielfachheitDatum)
+    return k->getZahl();
+  else
+    return 1;
 }
 
 
 
+int ListenKnoten::getImpliziteLaenge() const {
+  return getLaengeBis(getLaenge());
+}
+
+
+
+int ListenKnoten::getLaengeBis(int nr) const {
+  int ret=0;
+  for (int i=0; i<nr; i++)
+    ret += getVielfachheit(i);
+  return ret;
+}
+
+
+const DatenKnoten * ListenKnoten::getDatum(int nr,
+					   int solltyp /*= type_EgalDatum*/) {
+  Knoten * k = mKinder.at(nr);
+  CASSERT(k->type() == type_DatenKnoten);
+  return ((DatenKnoten *) k)->assert_datatype(solltyp);
+}
+
+
+
+const DatenKnoten * ListenKnoten::getKernDatum(int nr,
+					       int solltyp
+					       /*= type_EgalDatum*/) {
+  const DatenKnoten * d = getDatum(nr);
+  if (d->datatype() == type_VielfachheitDatum)
+    d = ((VielfachheitKnoten *) d)->getNurDasWort();
+  return d->assert_datatype(solltyp);
+}
+
+
+
+const DatenKnoten * ListenKnoten::getImplizitesDatum(int nr,
+						     int solltyp
+						     /*= type_EgalDatum*/) {
+  int nr_ = 0;
+  int vielfachheit = getVielfachheit(0);
+  while (nr>=vielfachheit) {
+    nr -= vielfachheit;
+    nr_++;
+    vielfachheit = getVielfachheit(nr_);
+  };
+  return getKernDatum(nr_,solltyp);
+}
+
+
+
+
+/*************************************************************************/
+/* DatenKnoten */
+
+const DatenKnoten * DatenKnoten::assert_datatype(int solltyp) const {
+  if ((solltyp != datatype()) && (solltyp!=type_EgalDatum)) {
+    __String solltyp_Darstellung = "<unknown type, please report>";
+    if (solltyp==type_WortDatum)
+      solltyp_Darstellung = "string";
+    if (solltyp==type_ZahlDatum)
+      solltyp_Darstellung = "int";
+    if (solltyp==type_VielfachheitDatum)
+      solltyp_Darstellung = "string * int";
+    throw Fehler(_("%s is of wrong type. %s expected"),
+		 (const char *) toString(),
+		 (const char *) solltyp_Darstellung);
+  }
+  return this;
+}
+
+
+
+
 /*************************************************************************/
 /* WortKnoten */
 
+__String WortKnoten::getWort(int rolle /*= wortrolle_einziges*/) const {
+  CASSERT(rolle==wortrolle_einziges);
+  return mWort;
+}
 
 __String WortKnoten::toString() const {
   return mWort;
@@ -501,3 +593,41 @@ __String WortKnoten::toString() const {
 
 
 
+
+/*************************************************************************/
+/* ZahlKnoten */
+
+int ZahlKnoten::getZahl(int rolle /*= zahlrolle_einziges*/) const {
+  CASSERT(rolle==zahlrolle_einzige);
+  return mZahl;
+}
+
+__String ZahlKnoten::toString() const {
+  __String ret;
+  ret.sprintf("%d", mZahl);
+  return ret;
+}
+
+
+
+
+/*************************************************************************/
+/* VielfachheitKnoten */
+
+int VielfachheitKnoten::getZahl(int rolle /*= zahlrolle_einzige*/) const {
+  CASSERT(rolle==zahlrolle_einzige);
+  return mZahl;
+}
+
+__String VielfachheitKnoten::getWort(int rolle
+				     /*= wortrolle_einziges*/) const {
+  CASSERT(rolle==wortrolle_einziges);
+  return mWort;
+}
+
+__String VielfachheitKnoten::toString() const {
+  __String ret;
+  ret.sprintf("%s * %d",(const char *) mWort,mZahl);
+  return ret;
+}
+
