@@ -63,6 +63,18 @@ LevelDaten::LevelDaten(): mLevelConf(new DatenDatei()),
 /** */
 LevelDaten::~LevelDaten() {
   delete mLevelConf;
+
+  for (int bnr=mAnzFarben-1; bnr>0; bnr--)
+    if (mSorten[bnr]!=mSorten[bnr-1])
+      delete mSorten[bnr];
+  if (mAnzFarben>0) /* wer wei, was uns noch so einfllt */
+    delete mSorten[0];
+
+  delete mSorten[blopart_grau];
+  delete mSorten[blopart_gras];
+  delete mSorten[blopart_keins];
+  delete mSorten[blopart_global];
+
 }
 
 
@@ -127,7 +139,8 @@ void LevelDaten::ladLevelConf() {
     int l = lena->getLaenge();
     mIntLevelNamen.resize(l);
     for (int i = 0; i < l; i++)
-      mIntLevelNamen.insert(i, new __String(lena->getWort(i)));
+      mIntLevelNamen.insert(i, new __String(lena->getDatum(i,type_WortDatum)
+					    ->getWort()));
   }
 
   /* OK, Laden war erfolgreich. */
@@ -186,20 +199,22 @@ void LevelDaten::ladLevel(int nr, int spz) {
 
     /* Level-Name */
     verlangeSchluessel("name");
-    mLevelName = mLevelConf->getEintrag("name");
+    mLevelName = mLevelConf->getWortEintrag("name");
 
     /* Level-Autor */
     verlangeSchluessel("author");
-    mLevelAutor = mLevelConf->getEintrag("author");
+    mLevelAutor = mLevelConf->getWortEintrag("author");
 
     /* Beschreibungstext (optional) */
-    mBeschreibung = mLevelConf->getEintrag("description", "");
+    mBeschreibung = mLevelConf->getWortEintrag("description", "");
 
-    /* Wie viele Steine mssen zusammen, damit sie platzen? */
-    verlangeSchluessel("numexplode");
-    mPlatzAnzahl = mLevelConf->getZahlEintrag("numexplode");
-    if (mPlatzAnzahl < 1)
-      throw Fehler(_("numexplode < 1"));
+    /* Wie viele Steine mssen zusammen, damit sie platzen?
+       (optional, da je Sorte definierbar (mu man dann aber auch tun)) */
+    mPlatzAnzahlDefault = mLevelConf->getZahlEintrag("numexplode",
+						     PlatzAnzahl_undefiniert);
+    mPlatzAnzahlMin = PlatzAnzahl_undefiniert;
+    mPlatzAnzahlMax = PlatzAnzahl_undefiniert;
+    mPlatzAnzahlAndere = false;
 
     /* Hintergrundfarbe... (optional; Default: wei)
        Achtung: Die Hintergrundfarbe muss gesetzt werden, _bevor_
@@ -210,7 +225,7 @@ void LevelDaten::ladLevel(int nr, int spz) {
     /* Hintergrundbilchen (optional) */
     mMitHintergrundbildchen = mLevelConf->hatEintrag("bgpic");
     if (mMitHintergrundbildchen)
-      mHintergrundBild.laden(mLevelConf->getEintrag("bgpic"));
+      mHintergrundBild.laden(mLevelConf->getWortEintrag("bgpic"));
 
     /* Schriftfarbe... (optional; Default: dunkelgrau) */
     setSchriftFarbe(mLevelConf->getFarbEintrag("textcolor",
@@ -227,7 +242,7 @@ void LevelDaten::ladLevel(int nr, int spz) {
     /* Hetzrandbildchen (optional) */
     mMitHetzbildchen = mLevelConf->hatEintrag("toppic");
     if (mMitHetzbildchen) {
-      mHetzBild.laden(mLevelConf->getEintrag("toppic"));
+      mHetzBild.laden(mLevelConf->getWortEintrag("toppic"));
   	
       /* Hetzrandberlapp (optional) */
       mHetzrandUeberlapp =
@@ -265,7 +280,8 @@ void LevelDaten::ladLevel(int nr, int spz) {
     ListenKnoten * picsnamen;
     verlangeSchluessel("pics");
     picsnamen = mLevelConf->getListenEintrag("pics");
-    mAnzFarben = picsnamen->getLaenge();
+    mAnzFarbnamen = picsnamen->getLaenge();
+    mAnzFarben = picsnamen->getImpliziteLaenge();
     if (mAnzFarben < 1)
       throw Fehler(_("#pics < 1"));
   	
@@ -299,20 +315,35 @@ void LevelDaten::ladLevel(int nr, int spz) {
     mNachbarStapelHoehe = 0;
 
     /* Farb-Bilder laden */
+    int bnr = 0;
+    for (int bnnr = 0; bnnr < mAnzFarbnamen; bnnr++) {
+      mSorten[bnr] = new Sorte(picsnamen->getKernDatum(bnnr,type_WortDatum)
+			       ->getWort(),
+			 blopart_farbe);
+      bnr++;
+      for (int i = picsnamen->getVielfachheit(bnnr)-1; i>0; i--) {
+	mSorten[bnr]=mSorten[bnr-1];
+	bnr++;
+      }
+    }
+      /*
     for (int bnr = 0; bnr < mAnzFarben; bnr++)
-      mSorten[bnr].laden(picsnamen->getWort(bnr), blopart_farbe);
+      mSorten[bnr].laden(picsnamen->getImplizitesDatum(bnr,type_WortDatum)
+			 ->getWort(),
+			 blopart_farbe);
+      */
 
     /* Grau-Bildchen laden */
     /* Achtung: "greypic" steht auch in knoten.cpp */
     verlangeSchluessel("greypic");
-    mSorten[blopart_grau].laden(mLevelConf->getEintrag("greypic"),
-                                blopart_grau);
+    mSorten[blopart_grau] = new Sorte(mLevelConf->getWortEintrag("greypic"),
+				      blopart_grau);
 
     /* Grasbildchen laden */
     /* Achtung: "startpic" steht auch in knoten.cpp */
     verlangeSchluessel("startpic");
-    mSorten[blopart_gras].laden(mLevelConf->getEintrag("startpic"),
-                                blopart_gras);
+    mSorten[blopart_gras] = new Sorte(mLevelConf->getWortEintrag("startpic"),
+				      blopart_gras);
 
     /* Leer-Bildchen (optional) */
     mMitLeerBildchen = mLevelConf->hatEintrag("emptypic");
@@ -320,11 +351,11 @@ void LevelDaten::ladLevel(int nr, int spz) {
        dann liefert getEintrag() "" zurck, und Sorte::laden() wei,
        dass es nur alle Werte auf Defaults setzen soll.
        Letztes true: Per default mit Rand verbinden */
-    mSorten[blopart_keins].laden(mLevelConf->getEintrag("emptypic"),
-                                 blopart_keins);
+    mSorten[blopart_keins] = new Sorte(mLevelConf->getWortEintrag("emptypic"),
+				       blopart_keins);
 
     /* Globaler Code (optional) */
-    mSorten[blopart_global].laden("global", blopart_global);
+    mSorten[blopart_global] = new Sorte("global", blopart_global);
     
     
     /* Ok, alle Sorten geladen. Wenn wir noch mNachbarStapelhoehe zu
@@ -336,7 +367,7 @@ void LevelDaten::ladLevel(int nr, int spz) {
 
 
    /* Musik (optional) */
-   mMusik = mLevelConf->getEintrag("music", "");
+   mMusik = mLevelConf->getWortEintrag("music", "");
 
   /***** KI-Player-Bewertungen *****/
     mKINHoehe =
@@ -472,7 +503,7 @@ __String LevelDaten::getLevelName(int nr) const {
     DatenDateiPush ddp(*mLevelConf, getIntLevelName(nr));
 
     verlangeSchluessel("name");
-    return mLevelConf->getEintrag("name");
+    return mLevelConf->getWortEintrag("name");
 
   } catch (Fehler f) {
     return "???";
