@@ -40,36 +40,50 @@ NachbarIterator & NachbarIterator::operator++() {
 
 	
 void NachbarIterator::setXY() {
-  char bx, by;
+  char bx, by, ri;
   switch (mNachbarschaft) {
   /* Die Nachbarschafts-Konstanten stehen in sorte.h */
+  /* Die ri-Konstanten auch; siehe dort zu welcher Buchstabe
+     was bedeutet. */
   case nachbarschaft_normal:
     bx = "1232"[mI];
     by = "2321"[mI];
+    ri = "caCA"[mI];
     break;
   case nachbarschaft_schraeg:
     bx = "1133"[mI];
     by = "1313"[mI];
+    ri = "dbBD"[mI];
     break;
   case nachbarschaft_6:
     bx =            "221133"[mI];
     by = ((mX0&1) ? "131212" : "132323")[mI];
+    ri =            "AadbBD"[mI];
     break;
   case nachbarschaft_6_schraeg:
     bx =            "1133"[mI];
     by = ((mX0&1) ? "1212" : "2323")[mI];
+    ri =            "dbBD"[mI];
     break;
   case nachbarschaft_springer:
     bx = "00134431"[mI];
     by = "13443100"[mI];
+    ri = "hgfeHGFE"[mI];
     break;
   case nachbarschaft_dame:
     bx = "12321133"[mI];
     by = "23211313"[mI];
+    ri = "caCAdbBD"[mI];
     break;
   case nachbarschaft_6_3d:
     bx = ((mX0&1) ? "04221" : "04223")[mI];
     by = ((mX0&1) ? "22132" : "22132")[mI];
+    ri = ((mX0&1) ? "cCAaI" : "cCAai")[mI];
+    break;
+  case nachbarschaft_garnichts:
+    bx = 0;
+    by = 0;
+    ri = 0;
     break;
   default:
     throw Fehler(_("Non-existent neighbours value."));
@@ -79,5 +93,11 @@ void NachbarIterator::setXY() {
   else {
     mX = mX0 + bx - '2';
     mY = mY0 + by - '2';
+    ri -= 'A';
+    mDir = mDirOpp = ri & 31;
+    if (ri >= 32) mDir += 16;
+    else mDirOpp += 16;
+    mDir = 1 << mDir;
+    mDirOpp = 1 << mDirOpp;
   }
 }
