@@ -11,6 +11,7 @@ typedef union {
   ListenKnoten * listenknoten;
   WortKnoten * wortknoten;
   Variable * variable;
+  int variablen_ort[2];
 } yystype;
 # define YYSTYPE yystype
 # define YYSTYPE_IS_TRIVIAL 1
@@ -39,17 +40,19 @@ typedef union {
 # define	DIV_TOK	278
 # define	MOD_TOK	279
 # define	RND_TOK	280
-# define	BONUS_TOK	281
-# define	MESSAGE_TOK	282
-# define	EXPLODE_TOK	283
-# define	REINWORT_TOK	284
-# define	WORT_TOK	285
-# define	NACHBAR8_TOK	286
-# define	NACHBAR6_TOK	287
-# define	ZAHL_TOK	288
-# define	HALBZAHL_TOK	289
-# define	BUCHSTABE_TOK	290
-# define	PFEIL_TOK	291
+# define	GGT_TOK	281
+# define	BONUS_TOK	282
+# define	MESSAGE_TOK	283
+# define	EXPLODE_TOK	284
+# define	REINWORT_TOK	285
+# define	WORT_TOK	286
+# define	NACHBAR8_TOK	287
+# define	NACHBAR6_TOK	288
+# define	NULLEINS_TOK	289
+# define	ZAHL_TOK	290
+# define	HALBZAHL_TOK	291
+# define	BUCHSTABE_TOK	292
+# define	PFEIL_TOK	293
 
 
 #endif /* not BISON_Y_TAB_H */
