@@ -44,7 +44,9 @@
 #define nachbarschaft_springer 4
 #define nachbarschaft_dame 5
 #define nachbarschaft_6_3d 6
-#define nachbarschaft_letzte 6
+#define nachbarschaft_garnichts 7
+#define nachbarschaft_letzte 7
+
 
 /** Event-Nummern in mEventCode. Die entsprechenden Strings stehen
     in sorte.cpp. */
@@ -53,7 +55,12 @@
 #define event_turn 2 // bei jedem drehen
 #define event_land 3 // kommt auf dem Boden auf (nur bei Fall)
 #define event_changeside 4 // wechselt zum anderen Spieler
-#define event_anz 5
+#define event_connect 5    // Verbindungen neu berechnen
+#define event_row_up1 6    // Reihe bekommen
+#define event_row_up2 7    // Reihe bekommen
+#define event_row_down1 8  // Reihe abgegeben
+#define event_row_down2 9  // Reihe abgegeben
+#define event_anz 10
 
 
 /* Blop-Arten / -Sortennummern. Die Nummern >= 0 sind die normalen
@@ -99,16 +106,15 @@ class Sorte {
 	
 
  public: 
-  Sorte();
-  ~Sorte();
-	
   /** Ldt die Sorte mit dem angegebenen Namen. Schaut auch in der
       entsprechenden Gruppe von mLevelConf nach, setzt die Gruppe
       aber danach zurck. blopart muss nur angegeben werden, damit ein
       paar Art-abhngige Defaults richtig gesetzt werden knnen.
       Throwt Fehler, wenn erfolglos. */
-  void laden(__String name, int blopart);
+  Sorte(__String name, int blopart);
   
+  ~Sorte();
+	
   
   
   
@@ -133,6 +139,8 @@ class Sorte {
   
   int getNachbarschaft() const;
   
+  int getPlatzAnzahl() const;
+  
   Code * getEventCode(int evt) const;
   
   Bilddatei * getBilddatei(int nr) const;
@@ -155,6 +163,8 @@ class Sorte {
   bool mKetteZaehltNurInnen;
   /** Was zhlt als Nachbarn im Sinne einer Kette? */
   int mNachbarschaft;
+  /** Wie viele Steine mssen zusammen, damit sie platzen? */
+  int mPlatzAnzahl;
 
   /** Alle Bildchen zu diesem Blop */
   QArray<Bilddatei *> mBilddateien;
