@@ -146,7 +146,7 @@
 
 Spielfeld::Spielfeld(bool re, QWidget *parent, const char *name )
   : QWidget(parent,name), mBild(grx * gric, gry * gric),
-    mDaten(re), mFall(this, re)
+    mDaten(re,this), mFall(this, re)
 {
   resize(grx * gric, gry * gric);
   setPalette( QPalette( white ) );
@@ -286,6 +286,7 @@ void Spielfeld::startLevel() {
   mDaten.init();
 		
   /* Kein Fallendes */
+  mFall.initialisiere();
   mFall.zerstoere();
 		
   /* Anfangsgraskonfiguration schreiben */
@@ -301,7 +302,7 @@ void Spielfeld::startLevel() {
   /* Zeilen durchgehen... */
   for (int i = 0; i < ld->mAnfangsZeilen->getLaenge(); i++) {
     int y = gry - ld->mAnfangsZeilen->getLaenge() + i;
-    __String zeile = ld->mAnfangsZeilen->getWort(i);
+    __String zeile = ld->mAnfangsZeilen->getDatum(i,type_WortDatum)->getWort();
     
     CASSERT(zeile.length() == grx);
     for (int x = 0; x < grx; x++) {
@@ -353,7 +354,7 @@ void Spielfeld::startLevel() {
       besetzt[i] = 0;
     /* !! Sehr provisorisch: Nur Nachbarschaftsverhltnisse von
        !! Farbe 0 bercksichtigen!!! */
-    for (NachbarIterator ni(&ld->mSorten[0], x, y); ni; ++ni) {
+    for (NachbarIterator ni(ld->mSorten[0], x, y); ni; ++ni) {
       if (mDaten.koordOK(ni.mX, ni.mY)) {
 	int f = mDaten.getFeld(ni.mX, ni.mY).getFarbe();
 	if (f != keine_farbe) besetzt[f]++;
@@ -409,20 +410,9 @@ void Spielfeld::stopLevel(bool malen, bool wegen_fehler /*= false*/) {
 }
 
 
-
-
-
-
-/** Ein Schritt vom Spiel.
-    Animationen und das Grafik-Update werden *nicht* gemacht.
-    Dazu muss animiere() aufgerufen werden.
-    (Weil alle Animationen innerhalb einer eigenen Gleichzeit
-    stattfinden sollen.) */
-void Spielfeld::spielSchritt() {
-
-  CASSERT(mModus != modus_keinspiel);
-
-
+/** Einmal pro Schritt aufrufen; kmmert sich ggf. um blinkendes
+    Message */
+void Spielfeld::blinkeMessage() {
   /* Ggf. Message-Text blinken lassen */
   if (mMessageZeit > 0) {
     mMessageZeit--;
@@ -436,67 +426,68 @@ void Spielfeld::spielSchritt() {
         setText(mMessageText, false);
     }
   }
+}
 
-  
-  /* Hetzrand runterbewegen und testen, ob dabei was berdeckt wird. */
-  bewegeHetzrand();
 
-  /* Ggf. sich selbst Graue schicken */
-  zufallsGraue();
-	
-  /* Debug-Zeilen: Einfluss der Hoch-Verschiebung austesten... */
-  //mHochVerschiebung = ("ABCDCB"[mZeit % 6] - 'A') * 10;
-  //setUpdateFastAlles();
+/** Sorgt dafr, dass bei Spielende bei geeigneter Gelegenheit auch in diesem
+    Spielfeld das Spiel beendet wird */
+void Spielfeld::testeSpielende() {
+  if (mModus != modus_testflopp) return;
 
+  if (!Cuyo::gCuyo->spielLaeuft()) {
+    /* Evtl. Fall platzen lassen */
+    if (mFall.existiert()) {
+      mFall.lassPlatzen();
+      mModus = modus_fallplatz;
+    } else
+      mModus = modus_warte_auf_stop;
+  }
+}
+
+
+/** Zusammenhangskomponenten bestimmen und ggf. Explosionen auslsen */
+void Spielfeld::testeFlopp() {
+  if (mModus != modus_testflopp) return;
+
+  /* Hat jemand einen Platztest bestellt? (Allerdings mit dem Platzen noch
+     warten, falls das Fall grade am zerfallen ist.)...
+     nderung: Es wird nicht mehr geschaut, ob jemand einen Platztest
+     bestellt hat. Etwas ineffektiver. */
+  if (!mFall.istEinzel()) {
+
+    /* Platzt was? (calcFlopp sendet ggf. auch die Grauen an den Mitspieler) */
+    if (calcFlopp()) {
+      mModus = modus_flopp;
+      gSound->playSample(mRechterSpieler, sample_explodier);
+    }
+  }
+}
+
+
+/** Um Fall kmmern. (Aber nicht darum, neues Fall zu erzeugen). */
+void Spielfeld::fallSchritt() {
   /* Um Fall kmmern. Macht auch ggf. notwendig gewordene
      Verwandlungen. */
   mFall.spielSchritt();
   /* Fr den KIPlayer: Jetzt ist das Fall nicht mehr neu. */
   mFallIstNeu = false;
-
-  /* Um Rberreihen kmmern */
-  rueberReihenSchritt();
-  
+};
 
 
-  /* Modus testflopp ist eine gute Gelegenheit zu prfen, ob das Spiel zu Ende
-     ist. */
-  if (mModus == modus_testflopp) {  // (1)
+/** Ein Schritt vom Spiel.
+    Animationen und das Grafik-Update werden *nicht* gemacht.
+    Dazu muss animiere() aufgerufen werden.
+    (Weil alle Animationen innerhalb einer eigenen Gleichzeit
+    stattfinden sollen.)
+    spielSchritt() sollte innerhalb einer Gleichzeit aufgerufen
+    werden fr evtl. auftretende Events. */
+void Spielfeld::spielSchritt() {
+
 
-    /* Ein guter Zeitpunkt fr's Spielende */
-    if (!Cuyo::gCuyo->spielLaeuft()) {
-				/* Evtl. Fall platzen lassen */
-      if (mFall.existiert()) {
-	mFall.lassPlatzen();
-	mModus = modus_fallplatz;
-      } else
-	mModus = modus_warte_auf_stop;
-    }
-  }  // Ende von mModus == modus_testflopp (1)
-		
-  /* Immernoch in Modus testflopp? Dann ist das Spiel noch nicht zu Ende.
-     Jetzt gleich prfen, ob's was zu platzen gibt, und ggf. in einen
-     passenden Modus wechseln, in dem weiter unten das Platzen behandelt wird. */
-  if (mModus == modus_testflopp) {  // (2)
-    /* Hat jemand einen Platztest bestellt? (Allerdings mit dem Platzen noch
-       warten, falls das Fall grade am zerfallen ist.)...
-       nderung: Es wird nicht mehr geschaut, ob jemand einen Platztest
-       bestellt hat. Etwas ineffektiver. */
-    if (/*mDaten.getTestPlatz() && */!mFall.istEinzel()) {
-    
-      /* Platzt was? (calcFlopp sendet ggf. auch die Grauen an den Mitspieler) */
-      if (calcFlopp()) {
-	mModus = modus_flopp;
-        gSound->playSample(mRechterSpieler, sample_explodier);
-      }
-    }
-  }  // Ende von mModus == modus_testflopp (2)
-  
   /* Immernoch in Modus testflopp? Dann wollte wohl nix explodieren. Also
      wieder in einen gravitations-Modus wechseln. */
      
-  if (mModus == modus_testflopp) {  // (3)
-			
+  if (mModus == modus_testflopp) {
     /* Keine Sofort-Explosion, also keine Kettenreaktion */
     mKettenreaktion = false;
 			
@@ -506,8 +497,7 @@ void Spielfeld::spielSchritt() {
       mModus = modus_rutschnach;
     else
       mModus = modus_neue_graue;			
-  
-  }  // Ende von mModus == modus_testflopp (3)
+  }  // Ende von mModus == modus_testflopp
 
 	
   switch (mModus) {
@@ -578,7 +568,7 @@ void Spielfeld::spielSchritt() {
 	  mModus = modus_warte_auf_stop;
       }
     }
-  		
+    
     break;
   }
   	  			  	
@@ -601,6 +591,11 @@ void Spielfeld::spielSchritt() {
     CASSERT(false);
   } // switch mModus
 
+
+  /* ggf. Spiel fr dieses Spielfeld beenden */
+  testeSpielende();
+
+
   /* Jetzt knnte man meinen, man will malUpdate() aufrufen, damit
      die Grafik upgedatet wird. Das wird aber im spteren animiere()-
      Aufruf getan. */
@@ -692,12 +687,19 @@ bool Spielfeld::calcFlopp() {
   /* Die Punkte werden nachher nur gesendet, wenn wirklich was
      explodiert ist. */
   int punkte = mKettenreaktion ? punkte_fuer_kettenreaktion : 0;
+  
+  /* Event an Blops senden, damit sie ihre Verbindungsspecials
+     ausfhren knnen */
+  mDaten.sendeConnectEvent();
 	
-  /* Anzahl der Grauen fr den anderen Spieler: Wenn die minimal mgliche
-     Blop-Zahl platzt, gibt's genau einen Grauen...
-     + ggf. welche fr Kettenreaktion */
-  int grz = -ld->mPlatzAnzahl + 1;
+  /* Anzahl der Grauen fr den anderen Spieler, wenn etwas platzt:
+     Mindestens 1. Die minimal mgliche Blop-Zahl, die platzt,
+     wird spter abgezogen. Und zwar von denen die grte.
+     Ggf. wird was fr Kettenreaktionen addiert */
+  int grz = 1;
   if (mKettenreaktion) grz += graue_bei_kettenreaktion;
+  /* Der grte PlatzAnzahl-Wert unter den Sorten, die jetzt platzen */
+  int maxPlatzAnzahl = 0;
 
   /* Array fr Zusammenhangskomponentensuche */
   int flopp[grx][gry];
@@ -713,19 +715,25 @@ bool Spielfeld::calcFlopp() {
       /* Normaler farbiger Blop, der noch nicht am platzen ist? */
       if (mDaten.getFeld(x, y).getArt() == blopart_farbe &&
 	  !mDaten.getFeld(x, y).getAmPlatzen()) {
-				/* Dann Kettengre berechnen... */
+	int PlatzAnzahl = ld->mSorten[mDaten.getFeld(x,y).getFarbe()]
+	  ->getPlatzAnzahl();
+				/* Dann Kettengre berechnen,... */
 	int anz = calcFloppRec(flopp, x, y,
 			       mDaten.getFeld(x, y).getFarbe(),
 			       -1);
-				
+
+        /* ... maxPlatzAnzahl fr grz aktualisieren ... */
+	if ((anz >= PlatzAnzahl) && (PlatzAnzahl > maxPlatzAnzahl))
+	  maxPlatzAnzahl = PlatzAnzahl;
+
 	/* ... und allen Blops in der Kette mitteilen. */
 	int neue_pt = calcFloppRec(flopp, x, y,
 				   mDaten.getFeld(x, y).getFarbe(),
 				   1, /* Gre mitteilen... */
-				   anz >= ld->mPlatzAnzahl, /* Platzen? */
+				   anz >= PlatzAnzahl, /* Platzen? */
 				   mKettenreaktion || !ld->mGrasBeiKettenreaktion, /* Auch Gras? */
 				   anz);
-	CASSERT(anz >= ld->mPlatzAnzahl  ||  neue_pt == 0);
+	CASSERT(anz >= PlatzAnzahl  ||  neue_pt == 0);
 				
 	/* Wenn's Punkte gab, ist wohl auch was geplatzt */
 	if (neue_pt > 0) {
@@ -734,7 +742,10 @@ bool Spielfeld::calcFlopp() {
 	  grz += anz;
 	}	
       }
-	
+
+  /* Jetzt kennen wir maxPlatzAnzahl endgltig, jetzt lassens wir's wirken */
+  grz -= maxPlatzAnzahl;
+
   /* Ist noch was explodiert? */
   if (wasPassiert) {
     /* Dann sende graue */
@@ -760,53 +771,59 @@ bool Spielfeld::calcFlopp() {
 int Spielfeld::calcFloppRec(int flopp[grx][gry], int x, int y,
 			    int n, int w, bool platzen /*= false*/,
 			    bool auch_gras /*= false*/, int anz /*= 0*/) {
-  int a = mDaten.getFeldArt(x, y);
-  /* Die Rberreihe zhlt beim explodieren nicht mit. */
-  if (y == gry) a = blopart_ausserhalb;
-
-  if (a == blopart_ausserhalb) // Auerhalb vom Spielfeld?
-    return 0;
-	
-  /* Nicht auerhalb? Dann knnen wir jetzt direkt auf das Blop zugreifen,
-     um nochmal genauer nachzufragen...
-     (Der a == blopart_ausserhalb-Test reicht noch nicht um zu wissen,
-     ob die Koordinaten ok sind, weil die Blop-Art
-     _ber_ dem Spielfeld blopart_nix ist.) */
-  if (mDaten.koordOK(x, y))
-    a = mDaten.getFeld(x, y).getArt();
-		
+  CASSERT(x >= 0 && x < grx && y >= 0 && y < gry);
+			    
   if (flopp[x][y] == w) // Hatten wir dieses Feld schon?
     return 0;
 			
+  int a = mDaten.getFeldArt(x, y);
+  Blop & b = mDaten.getFeld(x, y);
+
   switch (a) {
   case blopart_keins:
     return 0;		
-  case blopart_farbe:
-    if (mDaten.getFeld(x, y).getFarbe() != n) // Stein hat falsche Farbe
+  case blopart_farbe: {
+    /* Falsche Farbe? Ignorieren. */
+    if (b.getFarbe() != n)
       return 0;
-    else {
-      int ret = 0;
-      flopp[x][y] = w;
-      if (w == 1) {
-	mDaten.getFeld(x, y).setKettenGroesse(anz);
-	if (platzen) {
-	  mDaten.getFeld(x, y).lassPlatzen();
-	  ret = punkte_fuer_normales;
-	}
-      } else {
-	/* Normalerweise 1... nur z. B. beim Go-Level nicht immer. */
-	ret = mDaten.getFeld(x, y).getKettenBeitrag();
+      
+    int ret = 0;
+    flopp[x][y] = w;
+    if (w == 1) {
+      b.setKettenGroesse(anz);
+      if (platzen) {
+	b.lassPlatzen();
+	if (b.getVariable(spezvar_goalblob))
+	  ret = punkte_fuer_gras;
+	else
+  	  ret = punkte_fuer_normales;
       }
-      for (NachbarIterator i(&ld->mSorten[n], x, y); i; ++i)
-	ret += calcFloppRec(flopp, i.mX, i.mY, n, w, platzen, auch_gras, anz);
-      return ret;
+    } else {
+      /* Normalerweise 1... nur z. B. beim Go-Level nicht immer. */
+      ret = b.getKettenBeitrag();
     }
+    
+    /* Rekursiv weiteraufrufen: */
+    for (NachbarIterator i(ld->mSorten[n], x, y); i; ++i)
+      if (i.mX >= 0 && i.mX < grx && i.mY >= 0 && i.mY < gry) {
+        /* Nicht koordOk() verwenden, weil das die Rberreihe erlaubt, wenn
+	   sie existiert (bei y == gry) */
+	   
+	/* Noch checken, ob einer der Blops ein "inhibit" fr diese Verbindung
+	   gesetzt hat. */
+	if ((b.getVariable(spezvar_inhibit) & i.mDir) == 0 &&
+  	    (mDaten.getFeld(i.mX, i.mY).getVariable(spezvar_inhibit) & i.mDirOpp) == 0)
+          ret += calcFloppRec(flopp, i.mX, i.mY, n, w, platzen, auch_gras, anz);
+      }
+      
+    return ret;
+  }
   case blopart_grau:
     if (w == -1 || !platzen) {
       return 0;
     } else {
       flopp[x][y] = w;
-      mDaten.getFeld(x, y).lassPlatzen();
+      b.lassPlatzen();
       return punkte_fuer_graues;
     }
   case blopart_gras:
@@ -814,7 +831,7 @@ int Spielfeld::calcFloppRec(int flopp[grx][gry], int x, int y,
       return 0;
     } else {
       flopp[x][y] = w;
-      mDaten.getFeld(x, y).lassPlatzen();
+      b.lassPlatzen();
       return punkte_fuer_gras;
     }	
   }  // switch (a)
@@ -1049,7 +1066,6 @@ void Spielfeld::setMessage(__String mess) {
   mMessageZeit = message_gesamtzeit;
 }
 
-
 /** Wenn der Level gespiegelt ist, wird auch r gespiegelt */
 QRect Spielfeld::spiegelRect(const QRect & r){
   if (ld->mSpiegeln) {
@@ -1206,7 +1222,8 @@ bool Spielfeld::istGrasDa() const {
      nach oben, weil das Gras ja eher unten liegt... */
   for (int y = mDaten.getGrY() - 1; y >= 0; y--)
     for (int x = 0; x < grx; x++)
-      if (mDaten.getFeldArt(x, y) == blopart_gras)
+      if (mDaten.getFeldArt(x, y) == blopart_gras ||
+          mDaten.getFeld(x, y).getVariable(spezvar_goalblob))
         return true;
   return false;
 }
@@ -1218,9 +1235,14 @@ bool Spielfeld::istGrasDa() const {
 }
 
 /** Liefert einen Pointer auf die fallenden Blops zurck.
-    Wird von KIPlayer einmal am Anfang aufgerufen. */
-const Blop * Spielfeld::getFallPtr() {
-  return mFall.getBlopPtr();
+    Wird von KIPlayer einmal am Anfang aufgerufen
+    und gelegentlich bei @0 und  @1. */
+const Blop * Spielfeld::getFall() const {
+  return mFall.getBlop();
+}
+
+Blop * Spielfeld::getFall() {
+  return mFall.getBlop();
 }
 
 /** Liefert die Pos. zurck, an der neue Dinge oben
@@ -1298,7 +1320,8 @@ int Spielfeld::rutschNach(bool auchGraue){
     if (y >= 0) {	// wenn es leere Felder gab, dann nachrutschen
       for (; y > 0; y--) {
 	if (mDaten.getFeldArt(x, y - 1) != blopart_keins) {
-	  mDaten.verschiebBlop(x, y - 1, x, y);
+	  mDaten.getFeld(x, y) = mDaten.getFeld(x, y - 1);
+	  mDaten.getFeld(x, y - 1) = Blop(blopart_keins);
 	  if (y > hya + neues_fall_platz)
 	    ret |= rutschnach_wenig;
 	  else
@@ -1409,7 +1432,7 @@ void Spielfeld::rueberReihenSchritt() {
     if (mRechterSpieler) {
       /* von links: Reihe nach rechts schieben */
       for (int x = grx - 1; x > 0; x--)
-	mDaten.verschiebBlop(x - 1, gry, x, gry);
+        mDaten.getFeld(x, gry) = mDaten.getFeld(x - 1, gry);
       mDaten.getFeld(0, gry) = neuer;
 
       /* Seitenwechsel-Event */
@@ -1420,7 +1443,7 @@ void Spielfeld::rueberReihenSchritt() {
     } else {
       /* von rechts: Reihe nach links schieben */
       for (int x = 0; x < grx - 1; x++)
-	mDaten.verschiebBlop(x + 1, gry, x, gry);
+        mDaten.getFeld(x, gry) = mDaten.getFeld(x + 1, gry);
       mDaten.getFeld(grx - 1, gry) = neuer;
 
       /* Seitenwechsel-Event */
@@ -1435,10 +1458,14 @@ void Spielfeld::rueberReihenSchritt() {
     if (mRestRueberReihe == 0) {
       mRueberReihenModus = rrmodus_nix;
 
+      Blop::gGlobalBlop.execEvent(event_row_up1 + mRechterSpieler);
+
       /* Im Datenarray alles nach oben schieben. */
       for (int x = 0; x < grx; x++)
 	for (int y = 0; y < gry; y++)
-	  mDaten.verschiebBlop(x, y + 1, x, y);
+	  mDaten.getFeld(x, y) = mDaten.getFeld(x, y + 1);
+      /* In der Rberreihe sind noch alte Restblops; aber die Rberreihe
+         wird jetzt eh deaktiviert */
       mDaten.setRueberReihe(false);
       /* Optisch soll sich nix ndern; jetzt ist das Spielfeld wieder in
 	 Normalposition */
@@ -1503,11 +1530,16 @@ void Spielfeld::gebReihe(int h, int & ret){
     mRueberReihenModus = rrmodus_gib_rueber;
     mRestRueberReihe = grx;
     
+    Blop::gGlobalBlop.execEvent(event_row_down1 + mRechterSpieler);
+
     /* Im Datenarray alles nach unten schieben. */
-    for (int x = 0; x < grx; x++)
-      for (int y = gry; y > 0; y--)
-	mDaten.verschiebBlop(x, y - 1, x, y);
     mDaten.setRueberReihe(true);
+    for (int x = 0; x < grx; x++) {
+      for (int y = gry; y > 0; y--)
+	mDaten.getFeld(x, y) = mDaten.getFeld(x, y - 1);
+      /* Oben eine Reihe leer einfgen. */
+      mDaten.getFeld(x, 0) = Blop(blopart_keins);
+    }
     /* Optisch soll sich noch nix ndern... */
     mHochVerschiebung = gric;
     
@@ -1531,12 +1563,14 @@ void Spielfeld::gebStein(Blop & s){
     /* nach links... */
     s = mDaten.getFeld(0, gry);
     for (int x = 0; x < grx - 1; x++)
-      mDaten.verschiebBlop(x + 1, gry, x, gry);
+      mDaten.getFeld(x, gry) = mDaten.getFeld(x + 1, gry);
+    mDaten.getFeld(grx - 1, gry) = Blop(blopart_keins);
   } else {
     /* nach rechts... */
     s = mDaten.getFeld(grx - 1, gry);
     for (int x = grx - 1; x > 0; x--)
-      mDaten.verschiebBlop(x - 1, gry, x, gry);
+      mDaten.getFeld(x, gry) = mDaten.getFeld(x - 1, gry);
+    mDaten.getFeld(0, gry) = Blop(blopart_keins);
   }
 
   mRestRueberReihe--;
@@ -1560,6 +1594,9 @@ bool Spielfeld::bekommVielleichtReihe() {
   emit sigWillReihe(getHoehe(), erg);
   if (erg == bewege_reihe_ja) {
     mDaten.setRueberReihe(true);
+    /* Die Rberreihe lschen. (Da kann noch Mll von vorher drin sein. */
+    for (int x = 0; x < grx; x++)
+      mDaten.getFeld(x, gry) = Blop(blopart_keins);
     mRueberReihenModus = rrmodus_bekomm_hoch;
   }
   /* Wenn der andere Spieler grad noch mit einer alten Reihe beschftigt
